pub struct Router { /* private fields */ }Expand description
Router manages the mapping between Tenants and Raft Nodes
Implementations
Sourceimpl Router
impl Router
Sourcepub fn new(local_node_id: RaftNodeId) -> Self
pub fn new(local_node_id: RaftNodeId) -> Self
Create a new Router
Sourcepub fn update_route(&self, tenant_id: String, leader_node_id: RaftNodeId)
pub fn update_route(&self, tenant_id: String, leader_node_id: RaftNodeId)
Add or update a route for a tenant
Sourcepub fn remove_route(&self, tenant_id: &str)
pub fn remove_route(&self, tenant_id: &str)
Remove a route
Sourcepub fn route(&self, tenant_id: &str) -> Option<RouteResult>
pub fn route(&self, tenant_id: &str) -> Option<RouteResult>
Determine where to route a request for a given tenant
Sourcepub fn get_all_routes(&self) -> HashMap<String, RaftNodeId>
pub fn get_all_routes(&self) -> HashMap<String, RaftNodeId>
Get all known routes (for debugging/status)