pub async fn nlq_handler(
__arg0: State<AppState>,
__arg1: Json<QueryRequest>,
) -> impl IntoResponseExpand description
Handler for natural language to Cypher translation Uses the NLQ pipeline to convert plain English to Cypher queries.
pub async fn nlq_handler(
__arg0: State<AppState>,
__arg1: Json<QueryRequest>,
) -> impl IntoResponseHandler for natural language to Cypher translation Uses the NLQ pipeline to convert plain English to Cypher queries.